summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka/kafkacommon.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/parts/kafka/kafkacommon.h')
-rw-r--r--quanta/parts/kafka/kafkacommon.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/quanta/parts/kafka/kafkacommon.h b/quanta/parts/kafka/kafkacommon.h
index 0a1d25bd..fdec2aef 100644
--- a/quanta/parts/kafka/kafkacommon.h
+++ b/quanta/parts/kafka/kafkacommon.h
@@ -290,19 +290,19 @@ public:
* WARNING : baseNode is used as the rootNode.
* It will also try to merge text/Empty Nodes.
* @param node The node to insert.
* @param tqparentNode This Node will be the tqparent of node.
* @param nextSibling This Node will be the next Sibling of Node. If null, node will be appended at
* the child list of tqparentNode.
* TODO: @param rootNode The rootNode of the tree we want to insert the Node (usually &baseNode).
* @param modifs The changes made are logged into modifs. Put 0L if you don't want to log
* and if you know what you're doing!
* @param merge Try to merge with the siblings if possible.
* @return Returns a pointer to the node inserted.
*/
- static Node* insertNode(Node *node, Node* tqparentNode, Node* nextSibling,
+ static Node* insertNode(Node *node, Node* parentNode, Node* nextSibling,
NodeModifsSet *modifs/**, Node **rootNode*/, bool merge = true);
- static Node* insertNode(Node *node, Node* tqparentNode, Node* nextSibling, NodeSelection& selection,
+ static Node* insertNode(Node *node, Node* parentNode, Node* nextSibling, NodeSelection& selection,
NodeModifsSet *modifs, bool merge = true);
/**
@@ -373,15 +373,15 @@ public:
* WARNING : baseNode is used as the rootNode.
* It will also try to merge text/Empty Nodes.
* @param node The root node of the Node subtree to insert.
* @param tqparentNode This Node will be the tqparent of node.
* @param nextSibling This Node will be the next Sibling of Node. If null, node will be appended at
* the child list of tqparentNode.
* @param modifs The changes made are logged into modifs. Put 0L if you don't want to log
* and if you know what you're doing!
* @param merge Try to merge with the siblings if possible.
* @return Returns a pointer to the node inserted.
*/
- static Node* insertNodeSubtree(Node *node, Node* tqparentNode, Node* nextSibling,
+ static Node* insertNodeSubtree(Node *node, Node* parentNode, Node* nextSibling,
NodeModifsSet *modifs, bool merge = true);
/**
@@ -401,7 +401,7 @@ public:
* @param modifs The changes made are logged into modifs.
* @return Returns a pointer to the node inserted.
*/
- static Node* insertNodeSubtree(Node *node, Node* tqparentNode, Node* nextSibling,
+ static Node* insertNodeSubtree(Node *node, Node* parentNode, Node* nextSibling,
Node* nextEndSibling, NodeModifsSet *modifs, bool merge = true);
/**
@@ -414,7 +414,7 @@ public:
static Node* DTDInsertNodeSubtree(Node *node, NodeSelectionInd& selection,
Node **cursorNode, long& cursorOffset, NodeModifsSet *modifs);
- static Node* DTDInsertNodeSubtree(Node* newNode, Node* tqparentNode, Node* nextSibling,
+ static Node* DTDInsertNodeSubtree(Node* newNode, Node* parentNode, Node* nextSibling,
NodeSelection& cursorHolder, NodeModifsSet *modifs);
/**
@@ -544,7 +544,7 @@ public:
/**
* Extract a node subtree in the tree. WARNING This function will log that the nodes were added.
- * This funtion not only extract the start node but also will extract inline tqparents.
+ * This funtion not only extract the start node but also will extract inline parents.
* @param startNode The node from which we start the removal.
* @param startOffset The offset of startNode from which we start the removal.
* @param endNode The node from which we end the removal.
@@ -576,7 +576,7 @@ public:
* Get a node subtree from the tree. It is similar to extractNodeSubtree()
* but it doesn't extract anything.
* It's useful to get a copy of the Node subtree from a selection, for example.
- * This funtion not only extract the start node but also will extract inline tqparents.
+ * This funtion not only extract the start node but also will extract inline parents.
* @param startNode The starting Node.
* @param startOffset If firstNode is a text, specify at which offset the new start Node will be splitted.
* @param endNode The ending Node.
@@ -630,7 +630,7 @@ public:
* @param nodeToMove The node to move :-)
* @param newParent The new tqparent of nodeToMove.
* @param newNextSibling The new next Sibling of nodeToMove. If null, node will be appended at
* the child list of tqparentNode.
* @param modifs The changes made are logged into modifs.
* @param merge Specifies if it should try to merge the Node at its new location.
*/
@@ -855,7 +855,7 @@ public:
/**
* Get the node's depth in the tree.
* @param node The node we want the depth.
- * @return Returns the depth of node. It is basically the number of tqparents of node.
+ * @return Returns the depth of node. It is basically the number of parents of node.
* It will return 0 if node has no tqparent Nodes, and -1 if node doesn't exists.
*/
static int nodeDepth(Node *node);
@@ -991,12 +991,12 @@ public:
static int childPosition(DOM::Node domNode);
/**
* Returns the position'th child of tqparentNode.
* @param tqparentNode The tqparent Node of the node to return.
* @param position We return the position'th child Node.
* @param fallback If set to true, it will always return a valid Node (except if there is no child!!)
*/
- static DOM::Node getChildNode(DOM::Node tqparentNode, int position, bool fallback = false);
+ static DOM::Node getChildNode(DOM::Node parentNode, int position, bool fallback = false);
/**
* Specify if a DOM::Node is inline (as specified in isInline()) or text.
@@ -1008,7 +1008,7 @@ public:
* Specify if tqparent supports the siblings DOM::Nodes starting from startNode to endNode
* according to the DTD dtd.
*/
- static bool tqparentSupports(DOM::Node tqparent, DOM::Node startNode, DOM::Node endNode,
+ static bool parentSupports(DOM::Node tqparent, DOM::Node startNode, DOM::Node endNode,
const DTDStruct* dtd);
@@ -290,19 +290,19 @@ public:
* It will also try to merge text/Empty Nodes.
* @param node The node to insert.
- * @param tqparentNode This Node will be the tqparent of node.
+ * @param parentNode This Node will be the tqparent of node.
* @param nextSibling This Node will be the next Sibling of Node. If null, node will be appended at
@@ -290,19 +290,19 @@ public:
* @param nextSibling This Node will be the next Sibling of Node. If null, node will be appended at
- * the child list of tqparentNode.
+ * the child list of parentNode.
* TODO: @param rootNode The rootNode of the tree we want to insert the Node (usually &baseNode).
* @param modifs The changes made are logged into modifs. Put 0L if you don't want to log
@@ -373,15 +373,15 @@ public:
* It will also try to merge text/Empty Nodes.
* @param node The root node of the Node subtree to insert.
- * @param tqparentNode This Node will be the tqparent of node.
+ * @param parentNode This Node will be the tqparent of node.
* @param nextSibling This Node will be the next Sibling of Node. If null, node will be appended at
@@ -373,15 +373,15 @@ public:
* @param nextSibling This Node will be the next Sibling of Node. If null, node will be appended at
- * the child list of tqparentNode.
+ * the child list of parentNode.
* @param modifs The changes made are logged into modifs. Put 0L if you don't want to log
* and if you know what you're doing!
@@ -630,7 +630,7 @@ public:
* @param newParent The new tqparent of nodeToMove.
* @param newNextSibling The new next Sibling of nodeToMove. If null, node will be appended at
- * the child list of tqparentNode.
+ * the child list of parentNode.
* @param modifs The changes made are logged into modifs.
* @param merge Specifies if it should try to merge the Node at its new location.
@@ -991,12 +991,12 @@ public:
static int childPosition(DOM::Node domNode);
/**
- * Returns the position'th child of tqparentNode.
- * @param tqparentNode The tqparent Node of the node to return.
+ * Returns the position'th child of parentNode.
+ * @param parentNode The tqparent Node of the node to return.
* @param position We return the position'th child Node.
* @param fallback If set to true, it will always return a valid Node (except if there is no child!!)